"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !exports.hasOwnProperty(p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGreaterVersion = exports.checkValid = exports.calculateNextIncrementLevel = exports.getHigherIncrementLevel = exports.isValidIncrementLevel = void 0;
const _ = require("lodash");
const semver = require("resin-semver");
const VALID_INCREMENT_LEVELS = ['patch', 'minor', 'major'];
exports.isValidIncrementLevel = (level) => {
    return _.includes(VALID_INCREMENT_LEVELS, level);
};
exports.getHigherIncrementLevel = (firstLevel, secondLevel) => {
    _.each([firstLevel, secondLevel], (level) => {
        if (level != null && !exports.isValidIncrementLevel(level)) {
            throw new Error(`Invalid increment level: ${level}`);
        }
    });
    if (!firstLevel && !secondLevel) {
        return null;
    }
    const firstLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, firstLevel);
    const secondLevelIndex = _.indexOf(VALID_INCREMENT_LEVELS, secondLevel);
    return VALID_INCREMENT_LEVELS[Math.max(firstLevelIndex, secondLevelIndex)];
};
exports.calculateNextIncrementLevel = (commits, options) => {
    if (_.isEmpty(commits)) {
        throw new Error('No commits to calculate the next increment level from');
    }
    return _.reduce(commits, (currentLevel, commit) => {
        const commitLevel = options.getIncrementLevelFromCommit(commit);
        return exports.getHigherIncrementLevel(commitLevel, currentLevel);
    }, null);
};
exports.checkValid = (version) => {
    if (!semver.valid(version)) {
        throw new Error(`Invalid version: ${version}`);
    }
    return true;
};
exports.getGreaterVersion = (versions) => {
    return _.first(versions
        .map((v) => {
        return v.trim();
    })
        .sort(semver.rcompare));
};
__exportStar(require("resin-semver"), exports);
//# sourceMappingURL=semver.js.map